# TclMilter - Tcl Interface to Sendmail's Milter (Mail Filter) API
# Copyright (C) 2005 Muonics & Michael Kirkham <mikek@muonics.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License Version 2,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

package require tcltest ; namespace import -force tcltest::*
package require Thread

proc MilterInit {} {
	# Load TclMilter first into a new thread
	if {![info exist ::MT]} {
		set ::MT [thread::create]

		thread::send $::MT [list package require Thread]
		thread::send $::MT [list lappend auto_path [file normalize .]]
		thread::send $::MT [list package require TclMilter]
		thread::send $::MT [list set ::TestThread [thread::id]]

		set ::milter_file "unix:[file join [file dirname [info script]] test.sock]"
		file delete $::milter_file

		thread::send $::MT [list milter configure -connection $::milter_file]
	}

	# Load milter into main thread so that it can be stopped
	package require TclMilter
}

set ::MyAddress "$env(USER)@$env(HOSTNAME)"

proc sendTestMessage { {delay 1000} {timeout 5 }} {
	package require smtp

	after $delay

	set body	"This is the TclMilter test body"
	set subject	"This is the TclMilter test subject"

    set token [mime::initialize -canonical text/plain -string $body]
    mime::setheader $token Subject $subject
    smtp::sendmessage $token -recipients $::MyAddress -servers localhost
    mime::finalize $token
}

